import { Block, Document, Inline, Text } from '@contentful/rich-text-types';
export type CommonNode = Text | Block | Inline;
export interface Next {
    (nodes: CommonNode[]): string;
}
export interface NodeRenderer {
    (node: Block | Inline, next: Next): string;
}
export interface RenderNode {
    [k: string]: NodeRenderer;
}
export interface RenderMark {
    [k: string]: (text: string) => string;
}
export interface Options {
    /**
     * Node renderers
     */
    renderNode?: RenderNode;
    /**
     * Mark renderers
     */
    renderMark?: RenderMark;
    /**
     * Keep line breaks and multiple spaces
     */
    preserveWhitespace?: boolean;
    /**
     * Strip empty trailing paragraph from the document
     */
    stripEmptyTrailingParagraph?: boolean;
}
/**
 * Serialize a Contentful Rich Text `document` to an html string.
 */
export declare function documentToHtmlString(richTextDocument: Document, options?: Partial<Options>): string;
